Author: adrian
Date: 2011-12-17 09:37:24 -0800 (Sat, 17 Dec 2011)
New Revision: 17226

Modified:
   django/trunk/django/conf/global_settings.py
   django/trunk/django/contrib/admin/static/admin/js/admin/ordering.js
   django/trunk/django/contrib/gis/geos/tests/test_geos.py
   django/trunk/django/contrib/sessions/tests.py
   django/trunk/django/core/management/__init__.py
   django/trunk/django/db/models/sql/query.py
   django/trunk/django/template/defaulttags.py
   django/trunk/django/views/debug.py
   django/trunk/tests/modeltests/force_insert_update/models.py
   django/trunk/tests/modeltests/prefetch_related/tests.py
   django/trunk/tests/regressiontests/defer_regress/tests.py
   django/trunk/tests/regressiontests/fixtures_regress/models.py
   django/trunk/tests/regressiontests/mail/tests.py
   django/trunk/tests/regressiontests/model_inheritance_regress/tests.py
   django/trunk/tests/regressiontests/multiple_database/tests.py
   django/trunk/tests/regressiontests/queries/tests.py
   django/trunk/tests/regressiontests/serializers_regress/tests.py
   django/trunk/tests/regressiontests/templates/filters.py
   django/trunk/tests/regressiontests/test_client_regress/models.py
Log:
Fixed various dodgy behaviours

Modified: django/trunk/django/conf/global_settings.py
===================================================================
--- django/trunk/django/conf/global_settings.py 2011-12-17 15:30:55 UTC (rev 
17225)
+++ django/trunk/django/conf/global_settings.py 2011-12-17 17:37:24 UTC (rev 
17226)
@@ -152,7 +152,7 @@
     },
 }
 
-# Classes used to implement db routing behaviour
+# Classes used to implement DB routing behavior.
 DATABASE_ROUTERS = []
 
 # The email backend to use. For possible shortcuts see django.core.mail.

Modified: django/trunk/django/contrib/admin/static/admin/js/admin/ordering.js
===================================================================
--- django/trunk/django/contrib/admin/static/admin/js/admin/ordering.js 
2011-12-17 15:30:55 UTC (rev 17225)
+++ django/trunk/django/contrib/admin/static/admin/js/admin/ordering.js 
2011-12-17 17:37:24 UTC (rev 17226)
@@ -11,7 +11,7 @@
     setOrder(input.value.split(','));
     input.disabled = true;
     draw();
-    // Now initialise the dragging behaviour
+    // Now initialize the dragging behavior
     var limit = (lis.length - 1) * height;
     for (var i = 0; i < lis.length; i++) {
         var li = lis[i];

Modified: django/trunk/django/contrib/gis/geos/tests/test_geos.py
===================================================================
--- django/trunk/django/contrib/gis/geos/tests/test_geos.py     2011-12-17 
15:30:55 UTC (rev 17225)
+++ django/trunk/django/contrib/gis/geos/tests/test_geos.py     2011-12-17 
17:37:24 UTC (rev 17226)
@@ -892,11 +892,11 @@
 
     def test23_transform_nosrid(self):
         """ Testing `transform` method (no SRID) """
-        # raise a warning if SRID <0/None
+        # Raise a warning if SRID <0/None.
         import warnings
         print "\nBEGIN - expecting Warnings; safe to ignore.\n"
 
-        # test for do-nothing behaviour.
+        # Test for do-nothing behavior.
         try:
             # Keeping line-noise down by only printing the relevant
             # warnings once.

Modified: django/trunk/django/contrib/sessions/tests.py
===================================================================
--- django/trunk/django/contrib/sessions/tests.py       2011-12-17 15:30:55 UTC 
(rev 17225)
+++ django/trunk/django/contrib/sessions/tests.py       2011-12-17 17:37:24 UTC 
(rev 17226)
@@ -410,6 +410,6 @@
         This test tested cycle_key() which would create a new session
         key for the same session data. But we can't invalidate previously
         signed cookies (other than letting them expire naturally) so
-        testing for this behaviour is meaningless.
+        testing for this behavior is meaningless.
         """
         pass

Modified: django/trunk/django/core/management/__init__.py
===================================================================
--- django/trunk/django/core/management/__init__.py     2011-12-17 15:30:55 UTC 
(rev 17225)
+++ django/trunk/django/core/management/__init__.py     2011-12-17 17:37:24 UTC 
(rev 17226)
@@ -168,7 +168,7 @@
     def print_lax_help(self):
         """Output the basic options available to every command.
 
-        This just redirects to the default print_help() behaviour.
+        This just redirects to the default print_help() behavior.
         """
         OptionParser.print_help(self)
 

Modified: django/trunk/django/db/models/sql/query.py
===================================================================
--- django/trunk/django/db/models/sql/query.py  2011-12-17 15:30:55 UTC (rev 
17225)
+++ django/trunk/django/db/models/sql/query.py  2011-12-17 17:37:24 UTC (rev 
17226)
@@ -1249,7 +1249,7 @@
         case). Finally, 'negate' is used in the same sense as for add_filter()
         -- it indicates an exclude() filter, or something similar. It is only
         passed in here so that it can be passed to a field's extra_filter() for
-        customised behaviour.
+        customized behavior.
 
         Returns the final field involved in the join, the target database
         column (used for any 'where' constraint), the final 'opts' value and 
the

Modified: django/trunk/django/template/defaulttags.py
===================================================================
--- django/trunk/django/template/defaulttags.py 2011-12-17 15:30:55 UTC (rev 
17225)
+++ django/trunk/django/template/defaulttags.py 2011-12-17 17:37:24 UTC (rev 
17226)
@@ -474,7 +474,7 @@
 @register.tag
 def autoescape(parser, token):
     """
-    Force autoescape behaviour for this block.
+    Force autoescape behavior for this block.
     """
     args = token.contents.split()
     if len(args) != 2:

Modified: django/trunk/django/views/debug.py
===================================================================
--- django/trunk/django/views/debug.py  2011-12-17 15:30:55 UTC (rev 17225)
+++ django/trunk/django/views/debug.py  2011-12-17 17:37:24 UTC (rev 17226)
@@ -92,7 +92,7 @@
 class ExceptionReporterFilter(object):
     """
     Base for all exception reporter filter classes. All overridable hooks
-    contain lenient default behaviours.
+    contain lenient default behaviors.
     """
 
     def get_request_repr(self, request):

Modified: django/trunk/tests/modeltests/force_insert_update/models.py
===================================================================
--- django/trunk/tests/modeltests/force_insert_update/models.py 2011-12-17 
15:30:55 UTC (rev 17225)
+++ django/trunk/tests/modeltests/force_insert_update/models.py 2011-12-17 
17:37:24 UTC (rev 17226)
@@ -1,6 +1,6 @@
 """
 Tests for forcing insert and update queries (instead of Django's normal
-automatic behaviour).
+automatic behavior).
 """
 from django.db import models
 

Modified: django/trunk/tests/modeltests/prefetch_related/tests.py
===================================================================
--- django/trunk/tests/modeltests/prefetch_related/tests.py     2011-12-17 
15:30:55 UTC (rev 17225)
+++ django/trunk/tests/modeltests/prefetch_related/tests.py     2011-12-17 
17:37:24 UTC (rev 17226)
@@ -149,7 +149,7 @@
 
     def test_get(self):
         """
-        Test that objects retrieved with .get() get the prefetch behaviour
+        Test that objects retrieved with .get() get the prefetch behavior.
         """
         # Need a double
         with self.assertNumQueries(3):

Modified: django/trunk/tests/regressiontests/defer_regress/tests.py
===================================================================
--- django/trunk/tests/regressiontests/defer_regress/tests.py   2011-12-17 
15:30:55 UTC (rev 17225)
+++ django/trunk/tests/regressiontests/defer_regress/tests.py   2011-12-17 
17:37:24 UTC (rev 17226)
@@ -47,7 +47,7 @@
         self.assertEqual(r.item, i)
 
         # Some further checks for select_related() and inherited model
-        # behaviour (regression for #10710).
+        # behavior (regression for #10710).
         c1 = Child.objects.create(name="c1", value=42)
         c2 = Child.objects.create(name="c2", value=37)
         Leaf.objects.create(name="l1", child=c1, second_child=c2)

Modified: django/trunk/tests/regressiontests/fixtures_regress/models.py
===================================================================
--- django/trunk/tests/regressiontests/fixtures_regress/models.py       
2011-12-17 15:30:55 UTC (rev 17225)
+++ django/trunk/tests/regressiontests/fixtures_regress/models.py       
2011-12-17 17:37:24 UTC (rev 17226)
@@ -113,7 +113,7 @@
         return self.name
 
     # Person doesn't actually have a dependency on store, but we need to define
     # one to test the behaviour of the dependency resolution algorithm.
     def natural_key(self):
         return (self.name,)
     natural_key.dependencies = ['fixtures_regress.store']

Modified: django/trunk/tests/regressiontests/mail/tests.py
===================================================================
--- django/trunk/tests/regressiontests/mail/tests.py    2011-12-17 15:30:55 UTC 
(rev 17225)
+++ django/trunk/tests/regressiontests/mail/tests.py    2011-12-17 17:37:24 UTC 
(rev 17226)
@@ -75,9 +75,9 @@
         """
         Test for space continuation character in long (ascii) subject headers 
(#7747)
         """
-        email = EmailMessage('Long subject lines that get wrapped should use a 
space continuation character to get expected behaviour in Outlook and 
Thunderbird', 'Content', '[email protected]', ['[email protected]'])
+        email = EmailMessage('Long subject lines that get wrapped should use a 
space continuation character to get expected behavior in Outlook and 
Thunderbird', 'Content', '[email protected]', ['[email protected]'])
         message = email.message()
-        self.assertEqual(message['Subject'], 'Long subject lines that get 
wrapped should use a space continuation\n character to get expected behaviour 
in Outlook and Thunderbird')
+        self.assertEqual(message['Subject'], 'Long subject lines that get 
wrapped should use a space continuation\n character to get expected behavior in 
Outlook and Thunderbird')
 
     def test_message_header_overrides(self):
         """

Modified: django/trunk/tests/regressiontests/model_inheritance_regress/tests.py
===================================================================
--- django/trunk/tests/regressiontests/model_inheritance_regress/tests.py       
2011-12-17 15:30:55 UTC (rev 17225)
+++ django/trunk/tests/regressiontests/model_inheritance_regress/tests.py       
2011-12-17 17:37:24 UTC (rev 17226)
@@ -1,5 +1,5 @@
 """
-Regression tests for Model inheritance behaviour.
+Regression tests for Model inheritance behavior.
 """
 
 from __future__ import absolute_import
@@ -21,7 +21,7 @@
         # Regression for #7350, #7202
         # Check that when you create a Parent object with a specific reference
         # to an existent child instance, saving the Parent doesn't duplicate
         # the child. This behaviour is only activated during a raw save - it
         # is mostly relevant to deserialization, but any sort of CORBA style
         # 'narrow()' API would require a similar approach.
 

Modified: django/trunk/tests/regressiontests/multiple_database/tests.py
===================================================================
--- django/trunk/tests/regressiontests/multiple_database/tests.py       
2011-12-17 15:30:55 UTC (rev 17225)
+++ django/trunk/tests/regressiontests/multiple_database/tests.py       
2011-12-17 17:37:24 UTC (rev 17226)
@@ -934,7 +934,7 @@
                                   extra_arg=True)
 
 class TestRouter(object):
     # A test router. The behaviour is vaguely master/slave, but the
     # databases aren't assumed to propagate changes.
     def db_for_read(self, model, instance=None, **hints):
         if instance:
@@ -1010,7 +1010,7 @@
         self.assertEqual(Book.objects.db_manager('default').all().db, 
'default')
 
     def test_syncdb_selection(self):
-        "Synchronization behaviour is predicatable"
+        "Synchronization behavior is predictable"
 
         self.assertTrue(router.allow_syncdb('default', User))
         self.assertTrue(router.allow_syncdb('default', Book))
@@ -1042,7 +1042,7 @@
         dive = Book.objects.using('other').create(title="Dive into Python",
                                                   
published=datetime.date(2009, 5, 4))
 
         # First check the baseline behaviour
 
         self.assertEqual(router.db_for_read(User), 'other')
         self.assertEqual(router.db_for_read(Book), 'other')

Modified: django/trunk/tests/regressiontests/queries/tests.py
===================================================================
--- django/trunk/tests/regressiontests/queries/tests.py 2011-12-17 15:30:55 UTC 
(rev 17225)
+++ django/trunk/tests/regressiontests/queries/tests.py 2011-12-17 17:37:24 UTC 
(rev 17226)
@@ -1354,7 +1354,7 @@
         ann1.notes.add(n1)
         ann2 = Annotation.objects.create(name='a2', tag=t4)
 
-    # This next test used to cause really weird PostgreSQL behaviour, but it 
was
+    # This next test used to cause really weird PostgreSQL behavior, but it was
     # only apparent much later when the full test suite ran.
     #@unittest.expectedFailure
     def test_slicing_and_cache_interaction(self):

Modified: django/trunk/tests/regressiontests/serializers_regress/tests.py
===================================================================
--- django/trunk/tests/regressiontests/serializers_regress/tests.py     
2011-12-17 15:30:55 UTC (rev 17225)
+++ django/trunk/tests/regressiontests/serializers_regress/tests.py     
2011-12-17 17:37:24 UTC (rev 17226)
@@ -97,7 +97,7 @@
 def inherited_create(pk, klass, data):
     instance = klass(id=pk,**data)
     # This isn't a raw save because:
     #  1) we're testing inheritance, not field behaviour, so none
     #     of the field values need to be protected.
     #  2) saving the child class and having the parent created
     #     automatically is easier than manually creating both.

Modified: django/trunk/tests/regressiontests/templates/filters.py
===================================================================
--- django/trunk/tests/regressiontests/templates/filters.py     2011-12-17 
15:30:55 UTC (rev 17225)
+++ django/trunk/tests/regressiontests/templates/filters.py     2011-12-17 
17:37:24 UTC (rev 17226)
@@ -113,7 +113,7 @@
         'filter-make_list03': ('{% autoescape off %}{{ 
a|make_list|stringformat:"s"|safe }}{% endautoescape %}', {"a": 
mark_safe("&")}, u"[u'&']"),
         'filter-make_list04': ('{{ a|make_list|stringformat:"s"|safe }}', 
{"a": mark_safe("&")}, u"[u'&']"),
 
         # Running slugify on a pre-escaped string leads to odd behaviour,
         # but the result is still safe.
         'filter-slugify01': ("{% autoescape off %}{{ a|slugify }} {{ b|slugify 
}}{% endautoescape %}", {"a": "a & b", "b": mark_safe("a &amp; b")}, u"a-b 
a-amp-b"),
         'filter-slugify02': ("{{ a|slugify }} {{ b|slugify }}", {"a": "a & b", 
"b": mark_safe("a &amp; b")}, u"a-b a-amp-b"),

Modified: django/trunk/tests/regressiontests/test_client_regress/models.py
===================================================================
--- django/trunk/tests/regressiontests/test_client_regress/models.py    
2011-12-17 15:30:55 UTC (rev 17225)
+++ django/trunk/tests/regressiontests/test_client_regress/models.py    
2011-12-17 17:37:24 UTC (rev 17226)
@@ -976,7 +976,7 @@
 class ReadLimitedStreamTest(TestCase):
     """
     Tests that ensure that HttpRequest.body, HttpRequest.read() and
-    HttpRequest.read(BUFFER) have proper LimitedStream behaviour.
+    HttpRequest.read(BUFFER) have proper LimitedStream behavior.
 
     Refs #14753, #15785
     """
@@ -1017,7 +1017,7 @@
     """Regression tests for #15929."""
     # These tests are checking that certain middleware don't change certain
     # global state. Alternatively, from the point of view of a test, they are
-    # ensuring test isolation behaviour. So, unusually, it doesn't make sense 
to
+    # ensuring test isolation behavior. So, unusually, it doesn't make sense to
     # run the tests individually, and if any are failing it is confusing to run
     # them with any other set of tests.
 
@@ -113,7 +113,7 @@
 
     # Person doesn't actually have a dependency on store, but we need to define
-    # one to test the behaviour of the dependency resolution algorithm.
+    # one to test the behavior of the dependency resolution algorithm.
     def natural_key(self):
         return (self.name,)
@@ -21,7 +21,7 @@
         # Check that when you create a Parent object with a specific reference
         # to an existent child instance, saving the Parent doesn't duplicate
-        # the child. This behaviour is only activated during a raw save - it
+        # the child. This behavior is only activated during a raw save - it
         # is mostly relevant to deserialization, but any sort of CORBA style
         # 'narrow()' API would require a similar approach.
@@ -934,7 +934,7 @@
 
 class TestRouter(object):
-    # A test router. The behaviour is vaguely master/slave, but the
+    # A test router. The behavior is vaguely master/slave, but the
     # databases aren't assumed to propagate changes.
     def db_for_read(self, model, instance=None, **hints):
@@ -1042,7 +1042,7 @@
published=datetime.date(2009, 5, 4))
 
-        # First check the baseline behaviour
+        # First check the baseline behavior.
 
         self.assertEqual(router.db_for_read(User), 'other')
@@ -97,7 +97,7 @@
     instance = klass(id=pk,**data)
     # This isn't a raw save because:
-    #  1) we're testing inheritance, not field behaviour, so none
+    #  1) we're testing inheritance, not field behavior, so none
     #     of the field values need to be protected.
     #  2) saving the child class and having the parent created
@@ -113,7 +113,7 @@
{"a": mark_safe("&")}, u"[u'&']"),
 
-        # Running slugify on a pre-escaped string leads to odd behaviour,
+        # Running slugify on a pre-escaped string leads to odd behavior,
         # but the result is still safe.
         'filter-slugify01': ("{% autoescape off %}{{ a|slugify }} {{ b|slugify 

-- 
You received this message because you are subscribed to the Google Groups 
"Django updates" group.
To post to this group, send email to [email protected].
To unsubscribe from this group, send email to 
[email protected].
For more options, visit this group at 
http://groups.google.com/group/django-updates?hl=en.

Reply via email to